class Proxy {
  final String host;
  final String port;
  final String type;
  final String user;
  final String password;

  Proxy(
      {required this.host,
      required this.port,
      required this.type,
      required this.user,
      required this.password});

  factory Proxy.fromJson(Map<String, dynamic> json) {
    return Proxy(
        host: json['host'] ?? "",
        port: json['port'] ?? "",
        type: json['type'] ?? "",
        user: json['user'] ?? "",
        password: json['password'] ?? "");
  }

  @override
  String toString() {
    return '{"host":"$host", "port":"$port", "type":"$type", "user":"$user", "password":"$password"}';
  }

  bool operator ==(other) {
    return (other is Proxy && other.toString() == this.toString());
  }

  @override
  int get hashCode {
    return this.toString().hashCode;
  }

  int get priority {
    if (type == 'http') {
      return 0;
    } else if (type == 'https') {
      return 1;
    } else {
      return 2;
    }
  }

  String get pacString {
    if (type == 'http') {
      return 'PROXY $host:$port';
    } else if (type == 'https') {
      return 'PROXY $host:$port';
    } else {
      return 'DIRECT';
    }
  }

  String get pacStringWithCredentials {
    if (user.isEmpty || password.isEmpty) return pacString;

    if (type == 'http') {
      return 'PROXY $user:$password@$host:$port';
    } else if (type == 'https') {
      return 'PROXY $user:$password@$host:$port';
    } else {
      return 'DIRECT';
    }
  }
}
